@@ -7,24 +7,20 @@
 
 import flask
 from flask_restful import Resource
+from bigchaindb.web.authy import auth
 import platform
 
 from bigchaindb.web.views.base import base_ws_uri
 from bigchaindb import version
 from bigchaindb.web.websocket_server import EVENTS_ENDPOINT
 
-
 class RootIndex(Resource):
+    @auth.login_required
     def get(self):
-        docs_url = [
-            'https://docs.bigchaindb.com/projects/server/en/v',
-            version.__version__ + '/'
-        ]
         return flask.jsonify({
             'api': {
                 'v1': get_api_v1_info('/api/v1/')
             },
-            'docs': ''.join(docs_url),
             'software': 'saiive.chain',
             'version': version.__version__,
             'node': platform.node()
@@ -32,6 +28,7 @@ class RootIndex(Resource):
 
 
 class ApiV1Index(Resource):
+    @auth.login_required
     def get(self):
         return flask.jsonify(get_api_v1_info('/'))
 
