@@ -6,10 +6,12 @@
 from flask import current_app, request
 from flask_restful import reqparse, Resource
 
+from bigchaindb.web.authy import auth
 from bigchaindb.web.views import parameters
 
 
 class OutputListApi(Resource):
+    @auth.login_required
     def get(self):
         """API endpoint to retrieve a list of links to transaction
         outputs.
@@ -31,6 +33,7 @@ class OutputListApi(Resource):
                     for output in outputs]
 
 
+    @auth.login_required
     def post(self):
         """API endpoint to retrieve a list of links to transaction
         outputs.
