@@ -6,8 +6,10 @@
 from flask import current_app
 from flask_restful import Resource
 
+from bigchaindb.web.authy import auth
 
 class ValidatorsApi(Resource):
+    @auth.login_required
     def get(self):
         """API endpoint to get validators set.
 
